==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AdditionalNetworkDefinitionFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<A>{
  public AdditionalNetworkDefinitionFluentImpl() {
  }
  public AdditionalNetworkDefinitionFluentImpl(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance) {
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withRawCNIConfig(instance.getRawCNIConfig()); 
    this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private java.lang.String namespace;
  private java.lang.String rawCNIConfig;
  private io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder simpleMacvlanConfig;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public java.lang.String getRawCNIConfig() {
    return this.rawCNIConfig;
  }
  public A withRawCNIConfig(java.lang.String rawCNIConfig) {
    this.rawCNIConfig=rawCNIConfig; return (A) this;
  }
  public java.lang.Boolean hasRawCNIConfig() {
    return this.rawCNIConfig != null;
  }
  
  /**
   * Method is deprecated. use withRawCNIConfig instead.
   */
  @java.lang.Deprecated
  public A withNewRawCNIConfig(java.lang.String arg0) {
    return (A)withRawCNIConfig(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSimpleMacvlanConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig getSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig!=null?this.simpleMacvlanConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig buildSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig!=null?this.simpleMacvlanConfig.build():null;
  }
  public A withSimpleMacvlanConfig(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig simpleMacvlanConfig) {
    _visitables.get("simpleMacvlanConfig").remove(this.simpleMacvlanConfig);
    if (simpleMacvlanConfig!=null){ this.simpleMacvlanConfig= new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder(simpleMacvlanConfig); _visitables.get("simpleMacvlanConfig").add(this.simpleMacvlanConfig);} return (A) this;
  }
  public java.lang.Boolean hasSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluentImpl.SimpleMacvlanConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluentImpl.SimpleMacvlanConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(getSimpleMacvlanConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(getSimpleMacvlanConfig() != null ? getSimpleMacvlanConfig(): new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item) {
    return withNewSimpleMacvlanConfigLike(getSimpleMacvlanConfig() != null ? getSimpleMacvlanConfig(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AdditionalNetworkDefinitionFluentImpl that = (AdditionalNetworkDefinitionFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (rawCNIConfig != null ? !rawCNIConfig.equals(that.rawCNIConfig) :that.rawCNIConfig != null) return false;
    if (simpleMacvlanConfig != null ? !simpleMacvlanConfig.equals(that.simpleMacvlanConfig) :that.simpleMacvlanConfig != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  namespace,  rawCNIConfig,  simpleMacvlanConfig,  type,  additionalProperties,  super.hashCode());
  }
  public class SimpleMacvlanConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SimpleMacvlanConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder(this, item);
    }
    SimpleMacvlanConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder builder;
    public N and() {
      return (N) AdditionalNetworkDefinitionFluentImpl.this.withSimpleMacvlanConfig(builder.build());
    }
    public N endSimpleMacvlanConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/AdditionalNetworkDefinitionFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class AdditionalNetworkDefinitionFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent<A>{
  public AdditionalNetworkDefinitionFluentImpl() {
  }
  public AdditionalNetworkDefinitionFluentImpl(io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinition instance) {
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withRawCNIConfig(instance.getRawCNIConfig()); 
    this.withSimpleMacvlanConfig(instance.getSimpleMacvlanConfig()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private java.lang.String namespace;
  private java.lang.String rawCNIConfig;
  private io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder simpleMacvlanConfig;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public java.lang.String getRawCNIConfig() {
    return this.rawCNIConfig;
  }
  public A withRawCNIConfig(java.lang.String rawCNIConfig) {
    this.rawCNIConfig=rawCNIConfig; return (A) this;
  }
  public java.lang.Boolean hasRawCNIConfig() {
    return this.rawCNIConfig != null;
  }
  
  /**
   * Method is deprecated. use withRawCNIConfig instead.
   */
  @java.lang.Deprecated
  public A withNewRawCNIConfig(java.lang.String arg0) {
    return (A)withRawCNIConfig(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSimpleMacvlanConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig getSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig!=null?this.simpleMacvlanConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig buildSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig!=null?this.simpleMacvlanConfig.build():null;
  }
  public A withSimpleMacvlanConfig(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig simpleMacvlanConfig) {
    _visitables.get("simpleMacvlanConfig").remove(this.simpleMacvlanConfig);
    if (simpleMacvlanConfig!=null){ this.simpleMacvlanConfig= new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder(simpleMacvlanConfig); _visitables.get("simpleMacvlanConfig").add(this.simpleMacvlanConfig);} return (A) this;
  }
  public java.lang.Boolean hasSimpleMacvlanConfig() {
    return this.simpleMacvlanConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluentImpl.SimpleMacvlanConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> withNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluentImpl.SimpleMacvlanConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(getSimpleMacvlanConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfig() {
    return withNewSimpleMacvlanConfigLike(getSimpleMacvlanConfig() != null ? getSimpleMacvlanConfig(): new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<A> editOrNewSimpleMacvlanConfigLike(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item) {
    return withNewSimpleMacvlanConfigLike(getSimpleMacvlanConfig() != null ? getSimpleMacvlanConfig(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AdditionalNetworkDefinitionFluentImpl that = (AdditionalNetworkDefinitionFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (rawCNIConfig != null ? !rawCNIConfig.equals(that.rawCNIConfig) :that.rawCNIConfig != null) return false;
    if (simpleMacvlanConfig != null ? !simpleMacvlanConfig.equals(that.simpleMacvlanConfig) :that.simpleMacvlanConfig != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  namespace,  rawCNIConfig,  simpleMacvlanConfig,  type,  additionalProperties,  super.hashCode());
  }
  public class SimpleMacvlanConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.AdditionalNetworkDefinitionFluent.SimpleMacvlanConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SimpleMacvlanConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder(this, item);
    }
    SimpleMacvlanConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.SimpleMacvlanConfigBuilder builder;
    public N and() {
      return (N) AdditionalNetworkDefinitionFluentImpl.this.withSimpleMacvlanConfig(builder.build());
    }
    public N endSimpleMacvlanConfig() {
      return and();
    }
    
  }
  
}
